home | help
GMX-ROTMAT(1)			     GROMACS			   GMX-ROTMAT(1)

NAME
     gmx-rotmat - Plot the rotation matrix for fitting to a reference structure

SYNOPSIS
	gmx rotmat [-f [<.xtc/.trr/...>]] [-s [<.tpr/.gro/...>]] [-n [<.ndx>]]
		   [-o [<.xvg>]] [-b <time>] [-e <time>] [-dt <time>]
		   [-[no]w] [-xvg <enum>] [-ref <enum>] [-skip <int>]
		   [-[no]fitxy] [-[no]mw]

DESCRIPTION
     gmx  rotmat  plots the rotation matrix required for least squares fitting a
     conformation onto the reference conformation provided with -s.  Translation
     is  removed before fitting.  The output are the three vectors that give the
     new directions of the x, y and z directions of the reference  conformation,
     for  example:  (zx,zy,zz) is the orientation of the reference z-axis in the
     trajectory frame.

     This tool is useful for, for instance, determining  the  orientation  of  a
     molecule  at  an interface, possibly on a trajectory produced with gmx trj-
     conv -fit rotxy+transxy to remove the rotation in the x-y plane.

     Option -ref determines a reference structure for fitting, instead of  using
     the  structure  from -s. The structure with the lowest sum of RMSD's to all
     other structures is used.	Since the computational cost of  this  procedure
     grows with the square of the number of frames, the -skip option can be use-
     ful. A full fit or only a fit in the x-y plane can be performed.

     Option -fitxy fits in the x-y plane before determining the rotation matrix.

OPTIONS
     Options to specify input files:

     -f [<.xtc/.trr/...>] (traj.xtc)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -s [<.tpr/.gro/...>] (topol.tpr)
	    Structure+mass(db): tpr gro g96 pdb brk ent

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     Options to specify output files:

     -o [<.xvg>] (rotmat.xvg)
	    xvgr/xmgr file

     Other options:

     -b <time> (0)
	    Time of first frame to read from trajectory (default unit ps)

     -e <time> (0)
	    Time of last frame to read from trajectory (default unit ps)

     -dt <time> (0)
	    Only use frame when t MOD dt = first time (default unit ps)

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -xvg <enum> (xmgrace)
	    xvg plot formatting: xmgrace, xmgr, none

     -ref <enum> (none)
	    Determine the optimal reference structure: none, xyz, xy

     -skip <int> (1)
	    Use every nr-th frame for -ref

     -[no]fitxy (no)
	    Fit the x/y rotation before determining the rotation

     -[no]mw (yes)
	    Use mass weighted fitting

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			   GMX-ROTMAT(1)

home | help